# m203mylibrary

Library created for the m203 python project. It is adding new features to the library pybacktestchain

## Installation
```bash
$ pip install m203mylibrary
```

## Usage

Final goal : build option strategies and backtest them.

`test_function` can be used to test if the import of the package was sucessfull and evrything works well.

```python
from m203mylibrary.m203mylibrary import test_function

test_function()
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`m203mylibrary` was created by Mehmet Basagac. It is licensed under the terms of the MIT license.

## Credits

`m203mylibrary` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
